@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -27,7 +27,7 @@ from smartcard.PassThruCardService import PassThruCardService
 import smartcard.System
 
 
-class AbstractCardRequest:
+class AbstractCardRequest(object):
     """The base class for xxxCardRequest classes.
 
     A CardRequest is used for waitForCard() invocations and specifies what
@@ -35,7 +35,8 @@ class AbstractCardRequest:
 
     Known subclasses: smartcard.pcsc.PCSCCardRequest"""
 
-    def __init__(self, newcardonly=False, readers=None, cardType=None, cardServiceClass=None, timeout=1):
+    def __init__(self, newcardonly=False, readers=None,
+                 cardType=None, cardServiceClass=None, timeout=1):
         """Construct new CardRequest.
 
         newcardonly:        if True, request a new card; default is
