@@ -109,9 +109,9 @@ if __name__ == '__main__':
 
         if len(readers) < 1:
             raise error('No smart card readers')
-        print('Trying to retreive attributes of', readers[0])
 
         for reader in readers:
+            print('Trying to retreive attributes of', reader)
             hresult, hcard, dwActiveProtocol = SCardConnect(
                 hcontext,
                 reader,
@@ -132,7 +132,7 @@ if __name__ == '__main__':
                             print('-----------------', \
                                 attributes[i], \
                                 '-----------------')
-                            print('unsupported')
+                            print('error:', SCardGetErrorMessage(hresult))
 
                 finally:
                     hresult = SCardDisconnect(hcard, SCARD_UNPOWER_CARD)
