@@ -25,6 +25,7 @@ You should have received a copy of the GNU Lesser General Public License
 along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
+from __future__ import print_function
 from smartcard.Exceptions import NoCardException
 from smartcard.System import readers
 from smartcard.util import toHexString
@@ -33,11 +34,11 @@ for reader in readers():
     try:
         connection = reader.createConnection()
         connection.connect()
-        print reader, toHexString(connection.getATR())
+        print(reader, toHexString(connection.getATR()))
     except NoCardException:
-        print reader, 'no card inserted'
+        print(reader, 'no card inserted')
 
 import sys
 if 'win32' == sys.platform:
-    print 'press Enter to continue'
+    print('press Enter to continue')
     sys.stdin.read(1)
