@@ -27,6 +27,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
 
+from __future__ import print_function
 import unittest
 import string
 
@@ -39,8 +40,8 @@ sys.path += ['..']
 try:
     from local_config import expectedATRs, expectedReaders
     from local_config import expectedReaderGroups, expectedATRinReader
-except:
-    print 'execute test suite first to generate the local_config.py file'
+except ImportError:
+    print('execute test suite first to generate the local_config.py file')
     sys.exit()
 
 
@@ -59,8 +60,8 @@ class testcase_Card(unittest.TestCase):
             card = Card(reader, expectedATRinReader[str(reader)])
             mydict[card] = reader
 
-        for card in mydict.keys():
-            self.assert_(str(card.reader) in expectedReaders)
+        for card in list(mydict.keys()):
+            self.assertTrue(str(card.reader) in expectedReaders)
 
     def testcase_Card_FromReaders(self):
         """Create a Card from Readers and test that the response
@@ -75,8 +76,8 @@ class testcase_Card(unittest.TestCase):
                 cc.connect()
                 response, sw1, sw2 = cc.transmit(SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "9f 20": 2, "6e 0": 3}
-                self.assertEquals([], response)
-                self.assert_(
+                self.assertEqual([], response)
+                self.assertTrue(
                     "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
@@ -94,8 +95,8 @@ class testcase_Card(unittest.TestCase):
                 cc.connect()
                 response, sw1, sw2 = cc.transmit(SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "9f 20": 2, "6e 0": 3}
-                self.assertEquals([], response)
-                self.assert_(
+                self.assertEqual([], response)
+                self.assertTrue(
                     "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
@@ -105,14 +106,14 @@ class testcase_Card(unittest.TestCase):
         for reader in readers():
             card = Card(str(reader), expectedATRinReader[str(reader)])
             cardcopy = Card(str(reader), expectedATRinReader[str(reader)])
-            self.assertEquals(True, card == cardcopy)
-            self.assertEquals(True, not card != cardcopy)
+            self.assertEqual(True, card == cardcopy)
+            self.assertEqual(True, not card != cardcopy)
 
         for reader in readers():
             card = Card(str(reader), expectedATRinReader[str(reader)])
             cardcopy = Card(str(reader), [0, 0])
-            self.assertEquals(True, card != cardcopy)
-            self.assertEquals(True, not card == cardcopy)
+            self.assertEqual(True, card != cardcopy)
+            self.assertEqual(True, not card == cardcopy)
 
 
 def suite():
